@@ -13,9 +13,9 @@ use String::ShellQuote;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-29'; # DATE
+our $DATE = '2022-08-12'; # DATE
 our $DIST = 'Perinci-CmdLine-POD'; # DIST
-our $VERSION = '0.033'; # VERSION
+our $VERSION = '0.034'; # VERSION
 
 our @EXPORT_OK = qw(gen_pod_for_pericmd_script);
 
@@ -539,16 +539,16 @@ sub gen_pod_for_pericmd_script {
                     if (defined $gen_sc) { next unless $sc_name eq $gen_sc }
                     my $usage = $clidocdata{$sc_name}->{'usage_line.alt.fmt.pod'};
                     $usage =~ s/\[\[prog\]\]/$program_name $sc_name/;
-                    push @sectpod, "% $usage\n\n";
+                    push @sectpod, "$usage\n\n";
                 }
             } else {
-                push @sectpod, "% B<$program_name> [I<options>] [I<subcommand>] [I<arg>]...\n\n";
+                push @sectpod, "B<$program_name> [I<options>] [I<subcommand>] [I<arg>]...\n\n";
             }
             push @sectpod, "\n\n";
         } else {
             my $usage = $clidocdata{''}->{'usage_line.alt.fmt.pod'};
             $usage =~ s/\[\[prog\]\]/$program_name/;
-            push @sectpod, "% $usage\n\n";
+            push @sectpod, "$usage\n\n";
         }
         push @sectpod, "\n\nSee examples in the L</EXAMPLES> section.\n\n" if $has_examples;
 
@@ -1084,7 +1084,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.033 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-07-29.
+This document describes version 0.034 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2022-08-12.
 
 =head1 SYNOPSIS
 
@@ -1241,9 +1241,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
